openblas: An optimized implementation of BLAS (Basic Linear Algebra Subprograms)
================================================================================

Description
-----------

OpenBLAS is an optimized open library implementing the Basic Linear Algebra Subprograms
(BLAS) specification.

It is based on GotoBLAS2 1.13 BSD version.

License
-------

3-clause BSD license


SPKG Repository
---------------

https://www.openblas.net

GitHub page: https://github.com/xianyi/OpenBLAS

Releases: https://github.com/xianyi/OpenBLAS/releases


Upstream Contact
----------------

-  OpenBLAS users mailing list:

   https://groups.google.com/forum/#!forum/openblas-users

-  OpenBLAS developers mailing list:

   https://groups.google.com/forum/#!forum/openblas-dev
